name = "pyajax"

def buildscript(config):
    script  = "<script type='text/javascript'>"
    script += "$(function() {"

    for callback in config:
        uinputs = list(("'%s': $('#%s').val()" % (key, val)) for key, val in callback['handler']['input'].items())
        actions = list(("$('#%s').html(response.%s);" % (key, val)) for key, val in callback['handler']['action'].items())

        script += """
        $('#%s').bind('%s', function() {
            $.getJSON('%s', %s).done(function(response){%s});
            return false;
        });
        """ % (callback['handler']['event']['target'], 
               callback['handler']['event']['method'], 
               callback['handler']['event']['url'],
               "{"+",".join(uinputs)+"}",
               "".join(actions))

    script += "});" 
    script += "</script>" 

    return script


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='pyajax',
    version='0.0.4',
    url='https://github.com/washim/pyajax',
    license='BSD',
    author='Washim Ahmed',
    author_email='washim.ahmed@gmail.com',
    description='Develop ajax based analytical dashboard without writing any javascript.',
    long_description=long_description,
    packages=setuptools.find_packages(),
    zip_safe=False,
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)